==> push-0.9.2-sources.jar: com/flybits/android/push/utils/PushTemplateQueryParameters.java <==
package com.flybits.android.push.utils;

import android.support.annotation.NonNull;

import com.flybits.commons.library.models.internal.QueryParameters;

import java.util.ArrayList;
import java.util.Map;

/**
 * The {@link PushTemplateQueryParameters} class is used to define all the parameters set for the
 * GET request associated to {@link com.flybits.android.push.models.PushTemplate}.
 */
public class PushTemplateQueryParameters extends QueryParameters {

    private SortOrder order;

    private PushTemplateQueryParameters(Builder builder) {
        order           = builder.sort;
        addPaging(builder.limit, builder.offset);
    }

    /**
     * Get the list of query parameters that should be added to the GET request.
     *
     * @return A list of parameters that should be added to the GET query.
     */
    public Map<String, ArrayList<String>> getQueryParams(){

        Map<String, ArrayList<String>> params = super.getQueryParams();
        ArrayList<String> listOfSorts = new ArrayList<>();
        listOfSorts.add(order.getKey());
        params.put("order", listOfSorts);
        return params;
    }

    /**
     * The {@code Builder} class that defines all the possible filter options that can be used when
     * retrieving a list of Push Notifications.
     */
    public static class Builder {

        long limit;
        long offset;
        SortOrder sort;

        /**
         * Default Constructor that defines an empty {@code Builder}.
         */
        public Builder(){
            limit           = 10;
            offset          = 0;
            sort            = SortOrder.DESCENDING;
        }

        /**
         * Adds a paging mechanism to the request based on the number of returned results wanted and the
         * offset of the next X number of results, where X is a limit.
         *
         * @param limit The maximum number of returned objects.
         * @param offset The offset of where the next X number of response objects will be returned
         *               from where X is the limit.
         *
         * @return A {@code Builder} object where additional filter settings can be set.
         */
        public Builder addPaging(long limit, long offset){
            this.limit  = limit;
            this.offset = offset;
            return this;
        }

        /**
         * Build the {@code PushHistoryOptions} object to be used for constructing an HTTP request.
         *
         * @return {@code PushHistoryOptions} object which can be referenced by the SDK to get
         * specific information about a list of Push Notifications.
         */
        public PushTemplateQueryParameters build(){
            return new PushTemplateQueryParameters(this);
        }

        /**
         * Sets the sort order by created time of the response from the Server.
         *
         * @return A {@code Builder} object where additional filter settings can be set.
         */
        public Builder setSortOrder(@NonNull SortOrder order){
            if (order == null){
                return this;
            }

            this.sort   = order;
            return this;
        }
    }
}

==> push-0.9.9-sources.jar: com/flybits/android/push/utils/PushTemplateQueryParameters.java <==
package com.flybits.android.push.utils;

import android.support.annotation.NonNull;

import com.flybits.commons.library.models.internal.QueryBuilder;
import com.flybits.commons.library.models.internal.QueryParameters;

import java.util.ArrayList;
import java.util.Map;

/**
 * The {@link PushTemplateQueryParameters} class is used to define all the parameters set for the
 * GET request associated to {@link com.flybits.android.push.models.PushTemplate}.
 */
public class PushTemplateQueryParameters extends QueryParameters {

    private SortOrder order;

    private PushTemplateQueryParameters(Builder builder) {
        super(builder);
        order           = builder.sort;
    }

    /**
     * Get the list of query parameters that should be added to the GET request.
     *
     * @return A list of parameters that should be added to the GET query.
     */
    public Map<String, ArrayList<String>> getQueryParams(){

        Map<String, ArrayList<String>> params = super.getQueryParams();
        ArrayList<String> listOfSorts = new ArrayList<>();
        listOfSorts.add(order.getKey());
        params.put("order", listOfSorts);
        return params;
    }

    /**
     * The {@code Builder} class that defines all the possible filter options that can be used when
     * retrieving a list of Push Notifications.
     */
    public static class Builder extends QueryBuilder<Builder> {

        SortOrder sort;

        /**
         * Default Constructor that defines an empty {@code Builder}.
         */
        public Builder(){
            super();
            sort            = SortOrder.DESCENDING;
        }

        /**
         * Build the {@code PushHistoryOptions} object to be used for constructing an HTTP request.
         *
         * @return {@code PushHistoryOptions} object which can be referenced by the SDK to get
         * specific information about a list of Push Notifications.
         */
        public PushTemplateQueryParameters build(){
            return new PushTemplateQueryParameters(this);
        }

        /**
         * Sets the sort order by created time of the response from the Server.
         *
         * @return A {@code Builder} object where additional filter settings can be set.
         */
        public Builder setSortOrder(@NonNull SortOrder order){
            if (order == null){
                return this;
            }

            this.sort   = order;
            return this;
        }
    }
}
